@@ -8,7 +8,9 @@ use if $] >= 5.019, 'deprecate';
 # OS-specific modules don't do anything either - most of the work is
 # done in Module::Build::Base.
 
+use 5.006;
 use strict;
+use warnings;
 use File::Spec ();
 use File::Path ();
 use File::Basename ();
@@ -16,9 +18,8 @@ use Perl::OSType ();
 
 use Module::Build::Base;
 
-use vars qw($VERSION @ISA);
-@ISA = qw(Module::Build::Base);
-$VERSION = '0.4206';
+our @ISA = qw(Module::Build::Base);
+our $VERSION = '0.4207';
 $VERSION = eval $VERSION;
 
 # Inserts the given module into the @ISA hierarchy between
