@@ -1,7 +1,7 @@
 package Module::Build::Cookbook;
 use strict;
-use vars qw($VERSION);
-$VERSION = '0.4206';
+use warnings;
+our $VERSION = '0.4207';
 
 
 =head1 NAME
