@@ -1,12 +1,11 @@
 package Module::Build::Platform::MacOS;
 
 use strict;
-use vars qw($VERSION);
-$VERSION = '0.4206';
+use warnings;
+our $VERSION = '0.4207';
 $VERSION = eval $VERSION;
 use Module::Build::Base;
-use vars qw(@ISA);
-@ISA = qw(Module::Build::Base);
+our @ISA = qw(Module::Build::Base);
 
 use ExtUtils::Install;
 
